export function createLineChart(parent){
  console.log("creating linechart", parent)
  const  dataSource = 'https://gist.githubusercontent.com/Razpudding/f884509f465766aa4ad31e9cf18a696c/raw/3aa25817113f50f0a0695b87fffc4e234ac1c8d0/eyecolor-gender.json'

  const width = 1500
  const height = 400

  const svg = d3.select(parent).append('svg')
  svg.attr('width', width + "px")
  svg.attr('height', height + "px")
  const x = d3.scaleLinear()
  const y = d3.scaleLinear()

  d3.json(dataSource)
    .then(data => {
      data = data.filter(validColor)
      data = data.map(transformColor)
      data.sort( (a,b) => d3.ascending(a.b, b.b))
      drawMap(data)
      addScales()
  })
  console.log(svg.node())
  return svg.node()

  function drawMap(data){
    console.log("drawmap called with elements", data.length)
    // console.log(svg.selectAll(".dot"))
    let circles = svg.selectAll(".dot")
      .data(data)
      .enter()
      .append("circle")
        .attr("class", "dot")
        .attr("r", 3)
        .attr("cx", d => d.r * 3)
        //We'll add an opacity so circles can't hide behind others
        .attr("opacity", .9)
        //Note that y position is inversed, the more green, the LOWER the position
        .attr("cy", d => d.g)
        .attr("fill", d => d.eyeColor)
  }

  function addScales(){
    x.domain([0,255])
      .range([0, width])
    y.domain([0,255])
      //By putting height first, we're fixing the inverse effect of y
      .range([height,0])

    // console.log(x.range())
    // console.log("scaleTest", x(50))
    // console.log(svg.selectAll(".dot"))
    svg.selectAll(".dot")
      .transition()
        .delay(function(d, i) { return i * 20; })
        .attr("cx", d => x(d.r))
        .attr("cy", d => y(d.g))
        .attr("r", d => d.b / 10)
        .ease(d3.easeBounce)
        .duration(1500)
  }

  //Check if a color is valid with a regex tester
  function validColor(row){
    row.eyeColor = row.eyeColor.toUpperCase()
    return (/^((0x){0,1}|#{0,1})([0-9A-F]{8}|[0-9A-F]{6})$/).test(row.eyeColor) 
  }

  //Adds r,g,b properties
  function transformColor(row){
    if (row.eyeColor != "undefined"){
      row.eyeColor = row.eyeColor.replace("#","")
      row.r = parseInt(row.eyeColor.substring(0,2), 16)
      row.g = parseInt(row.eyeColor.substring(2,4), 16)
      row.b = parseInt(row.eyeColor.substring(4,6), 16)
      row.eyeColor = row.eyeColor.charAt(0) == "#"? row.eyeColor : "#" + row.eyeColor
    }
    // console.log(row)
    return row
  }
}